summaryrefslogtreecommitdiffstats
path: root/src/tools/qcstring.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tools/qcstring.h')
-rw-r--r--src/tools/qcstring.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/tools/qcstring.h b/src/tools/qcstring.h
index 372ae80..2c602e7 100644
--- a/src/tools/qcstring.h
+++ b/src/tools/qcstring.h
@@ -53,9 +53,9 @@
Safe and portable C string functions; extensions to standard string.h
*****************************************************************************/
-Q_EXPORT void *qmemmove( void *dst, const void *src, uint len );
+Q_EXPORT void *tqmemmove( void *dst, const void *src, uint len );
-Q_EXPORT char *qstrdup( const char * );
+Q_EXPORT char *tqstrdup( const char * );
Q_EXPORT inline uint qstrlen( const char *str )
{ return str ? (uint)strlen(str) : 0u; }
@@ -63,7 +63,7 @@ Q_EXPORT inline uint qstrlen( const char *str )
Q_EXPORT inline char *qstrcpy( char *dst, const char *src )
{ return src ? strcpy(dst, src) : 0; }
-Q_EXPORT char *qstrncpy( char *dst, const char *src, uint len );
+Q_EXPORT char *tqstrncpy( char *dst, const char *src, uint len );
Q_EXPORT inline int qstrcmp( const char *str1, const char *str2 )
{
@@ -77,9 +77,9 @@ Q_EXPORT inline int qstrncmp( const char *str1, const char *str2, uint len )
: ( str1 ? 1 : ( str2 ? -1 : 0 ) );
}
-Q_EXPORT int qstricmp( const char *, const char * );
+Q_EXPORT int tqstricmp( const char *, const char * );
-Q_EXPORT int qstrnicmp( const char *, const char *, uint len );
+Q_EXPORT int tqstrnicmp( const char *, const char *, uint len );
#ifndef QT_CLEAN_NAMESPACE
Q_EXPORT inline uint cstrlen( const char *str )
@@ -96,9 +96,9 @@ Q_EXPORT inline int cstrncmp( const char *str1, const char *str2, uint len )
#endif
-// qChecksum: Internet checksum
+// tqChecksum: Internet checksum
-Q_EXPORT Q_UINT16 qChecksum( const char *s, uint len );
+Q_EXPORT Q_UINT16 tqChecksum( const char *s, uint len );
/*****************************************************************************
QByteArray class
@@ -120,10 +120,10 @@ typedef QMemArray<char> QByteArray;
#endif
#ifndef QT_NO_COMPRESS
-Q_EXPORT QByteArray qCompress( const uchar* data, int nbytes );
+Q_EXPORT QByteArray tqCompress( const uchar* data, int nbytes );
Q_EXPORT QByteArray qUncompress( const uchar* data, int nbytes );
-Q_EXPORT inline QByteArray qCompress( const QByteArray& data)
-{ return qCompress( (const uchar*)data.data(), data.size() ); }
+Q_EXPORT inline QByteArray tqCompress( const QByteArray& data)
+{ return tqCompress( (const uchar*)data.data(), data.size() ); }
Q_EXPORT inline QByteArray qUncompress( const QByteArray& data )
{ return qUncompress( (const uchar*)data.data(), data.size() ); }
#endif